<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

namespace Invertus\SwedBank\Service;

use Invertus\SwedBank\Config\Config;
use Translate;

class PaymentMethodProvider
{
    /**
     * Get payment methods for country
     *
     * @param string $country
     *
     * @return array
     */
    public function getMethodsForCountry($country)
    {
        $methods = [];

        switch ($country) {
            case Config::BANK_LT:
                $methods = [
                    [
                        'id' => Config::PAYMENT_METHOD_CARD,
                        'name' => $this->l('Card payment')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SWEDBANK,
                        'name' => $this->l('Swedbank')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SEB,
                        'name' => $this->l('SEB')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_DNB,
                        'name' => $this->l('DNB')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_NORDEA,
                        'name' => $this->l('Nordea')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_DANSKE,
                        'name' => $this->l('Danske')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_PAYPAL,
                        'name' => $this->l('Paypal payment')
                    ]
                ];
                break;
            case Config::BANK_LV:
                $methods = [
                    [
                        'id' => Config::PAYMENT_METHOD_CARD,
                        'name' => $this->l('Card payment')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SWEDBANK,
                        'name' => $this->l('Swedbank')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SEB,
                        'name' => $this->l('SEB')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_CITADELE,
                        'name' => $this->l('Citadele')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_PAYPAL,
                        'name' => $this->l('Paypal payment')
                    ]
                ];
                break;
            case Config::BANK_EE:
                $methods = [
                    [
                        'id' => Config::PAYMENT_METHOD_CARD,
                        'name' => $this->l('Card payment')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SWEDBANK,
                        'name' => $this->l('Swedbank')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_SEB,
                        'name' => $this->l('SEB')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_NORDEA,
                        'name' => $this->l('Nordea')
                    ],
                    [
                        'id' => Config::PAYMENT_METHOD_PAYPAL,
                        'name' => $this->l('Paypal payment')
                    ]
                ];
                break;
        }

        return $methods;
    }

    /**
     * Translates text
     *
     * @param string $text
     *
     * @return string
     */
    protected function l($text)
    {
        return Translate::getModuleTranslation('swedbank', $text, 'PaymentMethodProvider');
    }
}
