/*
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

/**
 *
 * @type {number} - indicator of environment switch status
 */
var environmentEnabled = 0;

$(document).ready(function () {

    var hasError = getFormErrorStatus();
    if (hasError) {
        enableForm(false);
    }

    environmentEnabled = getEnabledEnvironmentStatus();
    var $disableStatus = getGlobalDisableStatus();
    if ($disableStatus) {
        disableCheckboxes();
    }

    /**
     * disables payment method checkboxes
     */
    function disableCheckboxes() {
        var $parent = getParent();
        var $checkboxes = $parent.find('input[name^="SB_PAYMENT_METHODS"]');
        $checkboxes.attr('disabled', true);
    }
    
    $(document).on('change', 'input[name^="SB_TERMS_AND_CONDITIONS"]', changeTermsAndConditionsEvent);
    $(document).on('change', 'input[name="SB_LIVE_ENVIRONMENT"], input[name="SB_TEST_ENVIRONMENT"]', changeEnvironmentEvent);

    /**
     * change terms and conditions event. Disables or enabled all form elements below
     */
    function changeTermsAndConditionsEvent() {
        if (!$(this).is(':checked')) {
            disableForm($(this).attr('name'));
        } else if($(this).is(':checked')) {
            if (environmentEnabled) {
                enableForm(true);
            } else {
                disableEnableEnvironment(false);
            }
        }
    }

    /**
     * changes environment event. disabled form below the switch
     */
    function changeEnvironmentEvent() {
        var $parent = getParent();
        if (parseInt($(this).val())) {
            environmentEnabled = 1;
            if ($('input[name^="SB_TERMS_AND_CONDITIONS"]').is(':checked')) {
                $parent.find('input').attr('disabled', false);
                $parent.find('select').attr('disabled', false);
                $parent.find('button[name="submitAddconfiguration"]').removeClass('disabled');
            }
        } else if (!parseInt($(this).val())) {
            $parent.find('input')
                .not('input[name="'+$(this).attr('name')+'"]')
                .not('input[name^="SB_TERMS_AND_CONDITIONS"]')
                .attr('disabled', true);
            $parent.find('select').attr('disabled', true);
            $parent.find('button[name="submitAddconfiguration"]').addClass('disabled');
            environmentEnabled = 0;
        }
    }

    /**
     *
     * @param {string} $currentElementName - disables everything excepts current input
     */
    function disableForm($currentElementName) {
        var $parent = getParent();
        $parent.find('input').not('input[name="'+$currentElementName+'"]').attr('disabled', true);
        $parent.find('select').attr('disabled', true);
        $parent.find('button[name="submitAddconfiguration"]').addClass('disabled');
    }

    /**
     *
     * @param {bool} status - determines if we need to enable or disable inputs
     */
    function disableEnableEnvironment(status)
    {
        $('input[name="SB_LIVE_ENVIRONMENT"]').attr('disabled', status);
        $('input[name="SB_TEST_ENVIRONMENT"]').attr('disabled', status);
    }

    /**
     *
     * @param {bool} ignoreDisableForm - determines if we need to ignore first initial form disable flag
     */
    function enableForm(ignoreDisableForm) {
        var $parent = getParent();
        $disableStatus = getGlobalDisableStatus();
        if ($disableStatus && !ignoreDisableForm) {
            disableEnableEnvironment(false);
            return;
        }

        $parent.find('input').attr('disabled', false);
        $parent.find('select').attr('disabled', false);
        $parent.find('button[name="submitAddconfiguration"]').removeClass('disabled');
    }

    /**
     *
     * @returns {Number} - gets value which is set on page load and indicates if this environment is editable or not
     */
    function getGlobalDisableStatus() {
        return parseInt($('#disable_form').val());
    }

    function getEnabledEnvironmentStatus() {
        if (true === $('input[id$="ENVIRONMENT_on"]').is(':checked')) {
            return 1;
        }
        return 0;
    }

    function getFormErrorStatus()
    {
        return parseInt($('input[name="hasError"]').val());
    }
});

/**
 * gets parent of the DOM we are manipulating
 * @returns {*|jQuery|HTMLElement}
 */
function getParent()
{
    return $('#configuration_form');
}